@@ -40,11 +40,7 @@ Implementation Notes
 """
 
 import gc
-
-try:
-    from displayio import Glyph
-except ImportError:
-    from fontio import Glyph
+from fontio import Glyph
 from .glyph_cache import GlyphCache
 
 __version__ = "0.0.0-auto.0"
